summaryrefslogtreecommitdiffstats
path: root/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp')
-rw-r--r--libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp b/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
index 922e5126..b25e5035 100644
--- a/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
+++ b/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
@@ -47,8 +47,8 @@ void KPartsGenericPart::load()
if ( m_part ) {
delete m_part;
}
- // "this" is both the parent widget and the parent object
- m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString::null, this, 0, this, 0 );
+ // "this" is both the tqparent widget and the tqparent object
+ m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), this, 0, this, 0 );
if ( m_part ) {
m_part->openURL( m_url );
m_part->widget()->show();
@@ -63,16 +63,16 @@ TQStringList KPartsWidgetPlugin::keys() const {
return TQStringList() << mykey;
}
-TQWidget * KPartsWidgetPlugin::create( const TQString & key, TQWidget * parent, const char * name ) {
+TQWidget * KPartsWidgetPlugin::create( const TQString & key, TQWidget * tqparent, const char * name ) {
if ( key == mykey )
- return new KPartsGenericPart( parent, name );
+ return new KPartsGenericPart( tqparent, name );
return 0;
}
TQString KPartsWidgetPlugin::group( const TQString & key ) const {
if ( key == mykey )
return "Display (KDE)";
- return TQString::null;
+ return TQString();
}
#if 0
@@ -84,19 +84,19 @@ TQIconSet KPartsWidgetPlugin::iconSet( const TQString & key ) const {
TQString KPartsWidgetPlugin::includeFile( const TQString & key ) const {
if ( key == mykey )
return "partplugin.h";
- return TQString::null;
+ return TQString();
}
TQString KPartsWidgetPlugin::toolTip( const TQString & key ) const {
if ( key == mykey )
return "Generic KParts viewer";
- return TQString::null;
+ return TQString();
}
TQString KPartsWidgetPlugin::whatsThis( const TQString & key ) const {
if ( key == mykey )
return "A widget to embed any KParts viewer, given a url and optionally a mimetype";
- return TQString::null;
+ return TQString();
}
bool KPartsWidgetPlugin::isContainer( const TQString & /*key*/ ) const {
@@ -104,14 +104,14 @@ bool KPartsWidgetPlugin::isContainer( const TQString & /*key*/ ) const {
}
/// Duplicated from kdelibs/kdecore/kdemacros.h.in for those with kdelibs < 3.4
-#ifndef KDE_Q_EXPORT_PLUGIN
-#define KDE_Q_EXPORT_PLUGIN(PLUGIN) \
- Q_EXTERN_C KDE_EXPORT const char* qt_ucm_query_verification_data(); \
- Q_EXTERN_C KDE_EXPORT QUnknownInterface* ucm_instantiate(); \
- Q_EXPORT_PLUGIN(PLUGIN)
+#ifndef KDE_TQ_EXPORT_PLUGIN
+#define KDE_TQ_EXPORT_PLUGIN(PLUGIN) \
+ TQ_EXTERN_C KDE_EXPORT const char* qt_ucm_query_verification_data(); \
+ TQ_EXTERN_C KDE_EXPORT TQUnknownInterface* ucm_instantiate(); \
+ TQ_EXPORT_PLUGIN(PLUGIN)
#endif
-KDE_Q_EXPORT_PLUGIN( KPartsWidgetPlugin )
+KDE_TQ_EXPORT_PLUGIN( KPartsWidgetPlugin )
#include "kpartsdesignerplugin.moc"